@@ -1,37 +1,37 @@
 epictmcmcsinr <- function(object, distancekernel, datatype, blockupdate, nsim, nchains, sus, suspower, trans, transpower, kernel, spark, delta, gamma.par, periodproposal, parallel, temp1, n, ni, net, dis, num, nsuspar, ntranspar) {
-    
+
         initial <- list(NULL)
         infperiodproposalin  <-  vector(mode="double", length = 2)
         infperiodproposalnr  <-  vector(mode="double", length = 2)
         deltain2prior  <-  vector(mode="double", length = 2)
         deltanr2prior  <-  vector(mode="double", length = 2)
         initial[[6]] <- list(NULL)
-        
+
         if (datatype == "known removal") {
-            
+
             anum66  <-  1
-            
+
             if (is.null(delta)) {
                 stop("Specify the arguments of the parameters of the incubation period distribution: delta",  call. =FALSE)
             } else {
-                
+
                 if (!is.list(delta)) {
                     stop("The argument \"delta\" must be a list of three:\n1) a scalar value of fixed shape parameter of the incubation period density.\n2) a vector of initial values of the rate parameter of the incubation period density with size equal to \"nchains\". \n3) a vector of the parameter values of the gamma prior distribution for the rate parameter.",  call.= FALSE)
                 }
-                
+
                 if (length(delta) != 3) {
                     stop("Error in entering the arguments of the delta parameters of the incubation period distribution: delta", call.=FALSE)
                 }
-                
+
                 if ( length(delta[[1]])>1) {
                     stop("Error in entering the arguments of the fixed shape parameter of the incubation period density: delta", call.=FALSE)
                 }
-                
+
                 initial[[6]][[2]]     <- matrix(0, ncol = nchains, nrow = 2)
                 deltanr2prior         <- c(0, 0)
                 initial[[6]][[1]]     <- matrix(0, ncol = nchains, nrow = 2)
                 initial[[6]][[1]][1,] <- rep(delta[[1]], nchains)
-                
+
                 if (is.vector(delta[[2]])) {
                     if (length(delta[[2]]) == nchains) {
                         initial[[6]][[1]][2,] <-  delta[[2]]
@@ -43,14 +43,14 @@ epictmcmcsinr <- function(object, distancekernel, datatype, blockupdate, nsim, n
                 } else {
                     stop("Error in entering the initial values of the delta parameter: delta[[2]]",  call.= FALSE)
                 }
-                
+
                 if (is.vector(delta[[3]]) & length(delta[[3]]) == 2) {
                     deltain2prior  <-  delta[[3]]
                 } else {
                     stop("Error in entering the parameter values of the gamma prior distribution of the incubation rate parameter: delta[[3]]",  call.= FALSE)
                 }
             }
-            
+
             if (is.null(periodproposal)) {
                 infperiodproposalin  <-  c(0, 0)
                 infperiodproposalnr  <-  c(0, 0)
@@ -59,49 +59,49 @@ epictmcmcsinr <- function(object, distancekernel, datatype, blockupdate, nsim, n
                     periodproposal          <-  matrix(periodproposal, ncol=2, nrow=1)
                     infperiodproposalin  <-  periodproposal[1, ]
                     infperiodproposalnr  <-  c(0, 0)
-                    
-                } else if (dim(periodproposal)[1]!=1 & dim(periodproposal)[2]!=2) {
+
+                } else if (all(dim(periodproposal)[1]!=1 & dim(periodproposal)[2]!=2) == TRUE) {
                     stop("The parameters of the proposal distribution should be entered as a 1 by 2 matrix or as a vector: periodproposal", call. = FALSE)
                 } else {
                     infperiodproposalin  <-  periodproposal[1, ]
                     infperiodproposalnr  <-  c(0, 0)
                 }
             }
-            
+
             if (is.null(blockupdate) ) {
                 blockupdate  <-  c(1, 1)
             }
-            
+
         } else if (datatype == "unknown removal") {
-            
+
             anum66  <-  2
-            
+
             if (is.null(delta)) {
                 stop("Specify the arguments of the parameters of the incubation and delay period distributions: delta",  call. =FALSE)
             } else {
-                
+
                 if (!is.list(delta)) {
                     stop("The argument \"delta\" must be a list of three:\n1) a vector of the fixed shape parameters of the incubation and delay period densities.\n2) a (2 by nchains) matrix of initial values of the incubation and delay rate parameters. \n3) a (2 by 2) matrix of the parameter values of the gamma prior distribution for the incubation and delay rate parameters.",  call.= FALSE)
                 }
-                
+
                 if (length(delta) != 3) {
                     stop("Error in entering the arguments of the delta parameters of the incubation and delay period distributions: delta", call.=FALSE)
                 }
-                
+
                 if (length(delta[[1]]) != 2) {
                     stop("Error in entering the arguments of the fixed shape parameters of the incubation and delay period densities: delta", call.=FALSE)
                 }
-                
+
                 initial[[6]][[2]]     <- matrix(0, ncol = nchains, nrow = 2)
                 initial[[6]][[2]][1,] <- rep(delta[[1]][2], nchains)
                 initial[[6]][[1]]     <- matrix(0, ncol = nchains, nrow = 2)
                 initial[[6]][[1]][1,] <- rep(delta[[1]][1], nchains)
-                
+
                 if (is.vector(delta[[2]]) & length(delta[[2]])==2) {
                     initial[[6]][[1]][2,] <-  rep(delta[[2]][1], nchains)
                     initial[[6]][[2]][2,] <-  rep(delta[[2]][2], nchains)
                 } else if(is.matrix(delta[[2]])) {
-                    if ((dim(delta[[2]])[1] ==2) & (dim(delta[[2]])[2] == nchains)) {
+                    if (all((dim(delta[[2]])[1] ==2) & (dim(delta[[2]])[2] == nchains)) == TRUE) {
                         initial[[6]][[1]][2,] <-  delta[[2]][1,]
                         initial[[6]][[2]][2,] <-  delta[[2]][2,]
                     } else {
@@ -110,9 +110,9 @@ epictmcmcsinr <- function(object, distancekernel, datatype, blockupdate, nsim, n
                 } else {
                     stop("Error in entering the initial values of the delta parameter: delta[[2]]",  call.= FALSE)
                 }
-                
+
                 if (is.matrix(delta[[3]])) {
-                    if ((dim(delta[[3]])[1] ==2) & (dim(delta[[3]])[2] == 2)) {
+                    if (all((dim(delta[[3]])[1] ==2) & (dim(delta[[3]])[2] == 2)) == TRUE) {
                         deltain2prior  <-  delta[[3]][1,]
                         deltanr2prior  <-  delta[[3]][2,]
                     } else {
@@ -122,8 +122,8 @@ epictmcmcsinr <- function(object, distancekernel, datatype, blockupdate, nsim, n
                     stop("The prior parameters of the incubation and delay periods must be entered as a 2 by 2 matrix: delta[[3]]",  call.= FALSE)
                 }
             }
-            
-            
+
+
             if (is.null(periodproposal) ) {
                 infperiodproposalin  <-  c(0, 0)
                 infperiodproposalnr  <-  c(0, 0)
@@ -132,26 +132,26 @@ epictmcmcsinr <- function(object, distancekernel, datatype, blockupdate, nsim, n
                     periodproposal          <-  matrix(periodproposal, ncol=2, nrow=2)
                     infperiodproposalin  <-  periodproposal[1, ]
                     infperiodproposalnr  <-  periodproposal[2, ]
-                } else if (dim(periodproposal)[1]!=2 & dim(periodproposal)[2]!=2) {
+                } else if (all(dim(periodproposal)[1]!=2 & dim(periodproposal)[2]!=2) == TRUE) {
                     stop("Enter the proposal distribution for updating the incubation and delay periods as a 2 by 2 matrix: periodproposal", call. = FALSE)
                 } else {
                     infperiodproposalin  <-  periodproposal[1, ]
                     infperiodproposalnr  <-  periodproposal[2, ]
                 }
             }
-            
+
             if (is.null(blockupdate) ) {
                 blockupdate  <-  c(1, 1)
             }
-            
+
         } else if (datatype == "known epidemic") {
-            
+
             blockupdate  <-  vector(mode="integer", length = 2)
-            
+
             if (!is.null(delta)) {
                 warning("The incubation and infectious period rates are not updated as the option of datatype is \"known epidemic\".", call. = TRUE)
             }
-            
+
             anum66                   <-  3
             infperiodproposalin      <-  c(0, 0)
             infperiodproposalnr      <-  c(0, 0)
@@ -160,25 +160,25 @@ epictmcmcsinr <- function(object, distancekernel, datatype, blockupdate, nsim, n
             blockupdate              <-  c(1, 1)
             initial[[6]][[1]]  <-  matrix(rep(0.0,nchains), ncol = nchains, nrow = 2)
             initial[[6]][[2]]  <-  matrix(rep(0.0,nchains), ncol = nchains, nrow = 2)
-            
+
         } else {
             stop("Specify the data type as \"known removal\",  \"unknown removal\" or \"known epidemic\": datatype ",  call. = FALSE)
         }
 
-        
+
         if (is.null(gamma.par)) {
-            
+
             anum55              <-  2
             priordistgammapar   <-  1
             gammaproposalvar    <-  0
             gammaprior          <-  c(1, 1)
             initial[[5]]        <-  rep(1,nchains)
-            
+
         } else {
             if (!is.list(gamma.par)) {
                 stop("The argument \"gamma.par\" must be a list of two:\n1) a vector of initial values of the gamma parameter of size equal to \"nchains\". \n2) a vector of prior distribution, prior parameter values, and proposal variance.",  call.= FALSE)
             }
-            
+
             if (length(gamma.par) != 2L) {
                 stop("The argument \"gamma.par\" must be a list of two:\n1) a vector of initial values of the gamma parameter of size equal to \"nchains\". \n2) a vector of prior distribution, prior parameter values, and proposal variance.",  call.= FALSE)
             } else {
@@ -187,7 +187,7 @@ epictmcmcsinr <- function(object, distancekernel, datatype, blockupdate, nsim, n
                 }
                 gammaproposalvar <-  gamma.par[[2]][4]
                 gammaprior <-  gamma.par[[2]][2:3]
-                
+
                 if (gamma.par[[2]][1] == "gamma") {
                     priordistgammapar  <-  1
                 } else if (gamma.par[[2]][1] == "half normal") {
@@ -197,7 +197,7 @@ epictmcmcsinr <- function(object, distancekernel, datatype, blockupdate, nsim, n
                 } else {
                     stop("The possible choices of the prior distribution are \"gamma\" ,  \"half normal\" or \"uniform\" distributions: gamma.par", call.=FALSE)
                 }
-                
+
                 if (length(gamma.par[[1]]) == nchains){
                     initial[[5]] <-  gamma.par[[1]]
                 } else if(length(gamma.par[[1]]) == 1) {
@@ -205,23 +205,23 @@ epictmcmcsinr <- function(object, distancekernel, datatype, blockupdate, nsim, n
                 } else {
                     stop("Error in entering the initial values of the gamma parameter: gamma.par[[1]]",  call.= FALSE)
                 }
-                
+
             }
         }
-        
+
         anum44  <-  kernel[[4]]
         kernelparproposalvar <-  kernel[[1]]
         kernelparprior <-  kernel[[3]]
         priordistkernelparpar  <-  kernel[[2]]
         initial[[4]] <-  kernel[[5]]
-        
+
         initial[[3]] <-  spark[[5]]
         anum33  <-  spark[[4]]
         sparkproposalvar  <-  spark[[1]]
         priordistsparkpar  <-  spark[[2]]
         sparkprior  <-  spark[[3]]
-        
-        
+
+
         anum11  <-  sus[[4]]
         initial[[1]] <- sus[[5]]
         suscov  <-  sus[[6]]
@@ -235,7 +235,7 @@ epictmcmcsinr <- function(object, distancekernel, datatype, blockupdate, nsim, n
         priordistpowersus <-  suspower[[2]]
         priorpar1powersus <-  suspower[[3]][[1]]
         priorpar2powersus <-  suspower[[3]][[2]]
-        
+
         anum22  <-  trans[[4]]
         initial[[2]] <- trans[[5]]
         transcov  <-  trans[[6]]
@@ -249,17 +249,17 @@ epictmcmcsinr <- function(object, distancekernel, datatype, blockupdate, nsim, n
         priordistpowertrans <-  transpower[[2]]
         priorpar1powertrans <-  transpower[[3]][[1]]
         priorpar2powertrans <-  transpower[[3]][[2]]
-        
+
         initial[[9]] <- temp1
-        
+
         anum2  <-  c(anum11, anum22, anum33, anum44, anum55, anum66, anum77, anum88)
-        
+
         cat("************************************************","\n")
         cat("* Start performing MCMC for the ", datatype," SINR ILM for","\n")
         cat(nsim, "iterations", "\n")
         cat("************************************************","\n")
-        
-        
+
+
         n=as.integer(n);
         nsim=as.integer(nsim);
         ni=as.integer(ni);
@@ -323,7 +323,7 @@ epictmcmcsinr <- function(object, distancekernel, datatype, blockupdate, nsim, n
         epidatmctim=matrix(0, ncol=n, nrow=nsim);
         epidatmcrem=matrix(0, ncol=n, nrow=nsim);
         loglik=matrix(0,ncol=1, nrow=nsim)
-        
+
         sinrmcmc<-list(n,nsim,ni,temp,num,anum2,nsuspar,ntranspar,net,dis,
         epidat,blockupdate,priordistsuspar, priordisttranspar, priordistkernelparpar,
         priordistpowersus, priordistpowertrans, priordistsparkpar, priordistgammapar,
@@ -335,7 +335,7 @@ epictmcmcsinr <- function(object, distancekernel, datatype, blockupdate, nsim, n
         priorpar2powertrans, kernelparprior, sparkprior, gammaprior, deltain2prior, deltanr2prior,
         susparop, powersusparop, transparop, powertransparop, kernelparop, sparkop, gammaop,
         deltain2op, deltanr2op, epidatmctim, epidatmcrem, loglik)
-        
+
         parallel.function <- function(i) {
             .Fortran("mcmcsinr_f",
             n=sinrmcmc[[1]], nsim=sinrmcmc[[2]], ni=sinrmcmc[[3]],
@@ -394,14 +394,14 @@ epictmcmcsinr <- function(object, distancekernel, datatype, blockupdate, nsim, n
             epidatmcrem=sinrmcmc[[63]],
             loglik=sinrmcmc[[64]], NAOK = TRUE)
         }
-        
-        
-        
-        
+
+
+
+
         if (nchains > 1L) {
-            
+
             if (parallel) {
-                
+
                 no_cores <- min(nchains, getOption("cl.cores", detectCores()))
                 cl <- makeCluster(no_cores)
                 varlist <- unique(c(ls(), ls(envir=.GlobalEnv), ls(envir=parent.env(environment()))))
@@ -419,25 +419,25 @@ epictmcmcsinr <- function(object, distancekernel, datatype, blockupdate, nsim, n
 
                 }
             }
-            
+
         } else if (nchains == 1L) {
             datmcmc22 <- parallel.function(1)
         }
-        
+
         names <- c(paste("Alpha_s[",seq_len(nsuspar),"]", sep = ""))
         namet <- c(paste("Alpha_t[",seq_len(ntranspar),"]", sep = ""))
         namepowers <- c(paste("Psi_s[",seq_len(nsuspar),"]", sep = ""))
         namepowert <- c(paste("Psi_t[",seq_len(ntranspar),"]", sep = ""))
-        
+
         if (nchains > 1L) {
-            
+
             result77   <-  list(NULL)
-            
+
             for (i in seq_len(nchains)){
-                
+
                 result777 <- NULL
                 namecols   <-  NULL
-                
+
                 if (anum2[1]==1) {
                     result777 <- cbind(result777, datmcmc22[[i]]$susparop    )
                     namecols <- c(namecols, names[1:nsuspar])
@@ -478,13 +478,13 @@ epictmcmcsinr <- function(object, distancekernel, datatype, blockupdate, nsim, n
                     result777 <- cbind(result777, datmcmc22[[i]]$deltanr2op)
                     namecols <- c(namecols, "Delay period rate")
                 }
-                
+
                 result777 <-cbind(result777, datmcmc22[[i]]$loglik)
                 namecols <-c(namecols, "Log-likelihood")
-                
+
                 result777  <- data.frame(result777)
                 colnames(result777)  <- namecols
-                
+
                 if (anum2[6]==3) {
                     result777 <- list(result777)
                 } else if (anum2[6]==1) {
@@ -492,11 +492,11 @@ epictmcmcsinr <- function(object, distancekernel, datatype, blockupdate, nsim, n
                 } else if (anum2[6]==2) {
                     result777 <- list(result777, datmcmc22[[i]]$epidatmctim, datmcmc22[[i]]$epidatmcrem)
                 }
-                
+
                 result77[[i]] <- result777
             }
         } else {
-            
+
             result77   <-  NULL
             namecols  <-  NULL
             if (anum2[1]==1) {
@@ -539,13 +539,13 @@ epictmcmcsinr <- function(object, distancekernel, datatype, blockupdate, nsim, n
                 result77 <- cbind(result77, datmcmc22$deltanr2op)
                 namecols <- c(namecols, "Delay period rate")
             }
-            
+
             result77 <-cbind(result77, datmcmc22$loglik)
             namecols <-c(namecols, "Log-likelihood")
-            
+
             result77  <- data.frame(result77)
             colnames(result77)  <- namecols
-            
+
             if (anum2[6]==3) {
                 result77 <- list(result77)
             } else if (anum2[6]==1) {
@@ -554,11 +554,11 @@ epictmcmcsinr <- function(object, distancekernel, datatype, blockupdate, nsim, n
                 result77 <- list(result77, datmcmc22$epidatmctim, datmcmc22$epidatmcrem)
             }
         }
-        
+
         # Creating an epictmcmc object:
-        
+
         if (nchains == 1){
-            
+
             if (length(result77) == 1) {
                 dim.results <- dim(result77[[1]])
                 mcmcsamp <- as.mcmc(result77[[1]][,-dim.results[2]])
@@ -566,14 +566,14 @@ epictmcmcsinr <- function(object, distancekernel, datatype, blockupdate, nsim, n
                 accpt <- 1-rejectionRate(as.mcmc(mcmcsamp))
                 num.iter <- niter(as.mcmc(mcmcsamp))
                 num.par <- nvar(as.mcmc(mcmcsamp))
-                
+
                 out <- list(compart.framework = object$type, kernel.type = object$kerneltype, data.assumption = datatype,
                 parameter.samples = mcmcsamp, log.likelihood = log.likelihood,
                 acceptance.rate = accpt, number.iteration = num.iter,
                 number.parameter = num.par, number.chains = nchains)
-                
+
             } else if (length(result77) == 2) {
-                
+
                 dim.results <- dim(result77[[1]])
                 mcmcsamp <- as.mcmc(result77[[1]][,-dim.results[2]])
                 log.likelihood <- as.mcmc(result77[[1]][,dim.results[2]])
@@ -583,15 +583,15 @@ epictmcmcsinr <- function(object, distancekernel, datatype, blockupdate, nsim, n
                 num.inf <- sum(object$epidat[,4]!=Inf)
                 infection.times.samples <- as.mcmc(result77[[2]][,1:num.inf])
                 Average.incubation.periods <- as.mcmc(apply(object$epidat[1:num.inf,4] - infection.times.samples,1,mean))
-                
+
                 out <- list(compart.framework = object$type, kernel.type = object$kerneltype, data.assumption = datatype,
                 parameter.samples = mcmcsamp, log.likelihood = log.likelihood,
                 acceptance.rate = accpt, number.iteration = num.iter,
                 number.parameter = num.par, number.chains = nchains, infection.times.samples = infection.times.samples,
                 Average.incubation.periods = Average.incubation.periods)
-                
+
             } else if (length(result77) == 3) {
-                
+
                 dim.results <- dim(result77[[1]])
                 mcmcsamp <- as.mcmc(result77[[1]][,-dim.results[2]])
                 log.likelihood <- as.mcmc(result77[[1]][,dim.results[2]])
@@ -603,7 +603,7 @@ epictmcmcsinr <- function(object, distancekernel, datatype, blockupdate, nsim, n
                 Average.incubation.periods <- as.mcmc(apply(object$epidat[1:num.inf,4] - infection.times.samples,1,mean))
                 removal.times.samples <- as.mcmc(result77[[3]][,1:num.inf])
                 Average.delay.periods <- as.mcmc(apply(removal.times.samples - object$epidat[1:num.inf,4],1,mean))
-                
+
                 out <- list(compart.framework = object$type, kernel.type = object$kerneltype, data.assumption = datatype,
                 parameter.samples = mcmcsamp, log.likelihood = log.likelihood,
                 acceptance.rate = accpt, number.iteration = num.iter,
@@ -611,33 +611,33 @@ epictmcmcsinr <- function(object, distancekernel, datatype, blockupdate, nsim, n
                 Average.incubation.periods = Average.incubation.periods,
                 removal.times.samples = removal.times.samples,
                 Average.delay.periods = Average.delay.periods)
-                
+
             }
-            
+
         } else{
-            
+
             if (length(result77[[1]]) == 1) {
                 dim.results <- dim(result77[[1]][[1]])
                 mcmcsamp <- list(NULL)
                 log.likelihood <- list(NULL)
                 accpt <- list(NULL)
-                
+
                 for (i in seq_len(nchains)) {
                     mcmcsamp[[i]] <- as.mcmc(result77[[i]][[1]][,-dim.results[2]])
                     accpt[[i]] <- 1-rejectionRate(as.mcmc(mcmcsamp[[i]]))
                     log.likelihood[[i]] <- as.mcmc(result77[[i]][[1]][,dim.results[2]])
                 }
-                
+
                 num.iter <- niter(as.mcmc(mcmcsamp[[1]]))
                 num.par <- nvar(as.mcmc(mcmcsamp[[1]]))
-                
+
                 out <- list(compart.framework = object$type, kernel.type = object$kerneltype, data.assumption = datatype,
                 parameter.samples = mcmcsamp, log.likelihood = log.likelihood,
                 acceptance.rate = accpt, number.iteration = num.iter,
                 number.parameter = num.par, number.chains = nchains)
-                
+
             } else if (length(result77[[1]]) == 2) {
-                
+
                 dim.results <- dim(result77[[1]][[1]])
                 mcmcsamp <- list(NULL)
                 log.likelihood <- list(NULL)
@@ -645,7 +645,7 @@ epictmcmcsinr <- function(object, distancekernel, datatype, blockupdate, nsim, n
                 num.inf <- sum(object$epidat[,4]!=Inf)
                 infection.times.samples <- list(NULL)
                 Average.incubation.periods <- list(NULL)
-                
+
                 for (i in seq_len(nchains)) {
                     mcmcsamp[[i]] <- as.mcmc(result77[[i]][[1]][,-dim.results[2]])
                     accpt[[i]] <- 1-rejectionRate(as.mcmc(mcmcsamp[[i]]))
@@ -653,18 +653,18 @@ epictmcmcsinr <- function(object, distancekernel, datatype, blockupdate, nsim, n
                     infection.times.samples[[i]] <- as.mcmc(result77[[i]][[2]][,seq_len(num.inf)])
                     Average.incubation.periods[[i]] <- as.mcmc(apply(object$epidat[seq_len(num.inf),4]-infection.times.samples[[i]],1,mean))
                 }
-                
+
                 num.iter <- niter(as.mcmc(mcmcsamp[[1]]))
                 num.par <- nvar(as.mcmc(mcmcsamp[[1]]))
-                
+
                 out <- list(compart.framework = object$type, kernel.type = object$kerneltype, data.assumption = datatype,
                 parameter.samples = mcmcsamp, log.likelihood = log.likelihood,
                 acceptance.rate = accpt, number.iteration = num.iter,
                 number.parameter = num.par, number.chains = nchains, infection.times.samples = infection.times.samples,
                 Average.incubation.periods = Average.incubation.periods)
-                
+
             } else if (length(result77[[1]]) == 3) {
-                
+
                 dim.results <- dim(result77[[1]][[1]])
                 mcmcsamp <- list(NULL)
                 log.likelihood <- list(NULL)
@@ -674,7 +674,7 @@ epictmcmcsinr <- function(object, distancekernel, datatype, blockupdate, nsim, n
                 Average.incubation.periods <- list(NULL)
                 removal.times.samples <- list(NULL)
                 Average.delay.periods <- list(NULL)
-                
+
                 for (i in seq_len(nchains)) {
                     mcmcsamp[[i]] <- as.mcmc(result77[[i]][[1]][,-dim.results[2]])
                     accpt[[i]] <- 1-rejectionRate(as.mcmc(mcmcsamp[[i]]))
@@ -684,10 +684,10 @@ epictmcmcsinr <- function(object, distancekernel, datatype, blockupdate, nsim, n
                     removal.times.samples[[i]] <- as.mcmc(result77[[i]][[3]][,seq_len(num.inf)])
                     Average.delay.periods[[i]] <- as.mcmc(apply(removal.times.samples[[i]] - object$epidat[seq_len(num.inf),4],1,mean))
                 }
-                
+
                 num.iter <- niter(as.mcmc(mcmcsamp))
                 num.par <- nvar(as.mcmc(mcmcsamp))
-                
+
                 out <- list(compart.framework = object$type, kernel.type = object$kerneltype, data.assumption = datatype,
                 parameter.samples = mcmcsamp, log.likelihood = log.likelihood,
                 acceptance.rate = accpt, number.iteration = num.iter,
@@ -695,9 +695,9 @@ epictmcmcsinr <- function(object, distancekernel, datatype, blockupdate, nsim, n
                 Average.incubation.periods = Average.incubation.periods,
                 removal.times.samples = removal.times.samples,
                 Average.delay.periods = Average.delay.periods)
-                
+
             }
-            
+
         }
-        
+
 }
