@@ -29,7 +29,7 @@
 
 plot.datagen<- function(x, plottype, time.index = NULL, ...) {
 
-    if (class(x) == "datagen") {
+    if (is(x, "datagen")) {
 
         k1 <- sum(x$epidat[,2] != Inf)
         n <- length(x$epidat[,1])
@@ -67,12 +67,12 @@ plot.datagen<- function(x, plottype, time.index = NULL, ...) {
 
                     op <- par(mar = c(5.9, 4.0, 1.5, 0.5), omi = c(0.2, 0.05, 0.15, 0.15), mfrow = c(a, b))
                     on.exit(par(op))
-                    
+
                     plot(x$location[, 1], x$location[, 2], xlim = c(floor(min(x$location[, 1])), ceiling(max(x$location[, 1]))),
                     ylim = c(floor(min(x$location[, 2])), ceiling(max(x$location[, 2]))), panel.first = grid(),
                     main =  paste("Infection time (",1,")"), xlab = "x", ylab = "y", col = "light gray", pch = 19)
                     points(x$location[x$epidat[1, 1], 1], x$location[x$epidat[1, 1], 2], col = "blue", pch = 16)
-                    
+
                     for (m in 2:length(ss)) {
                         plot(x$location[, 1], x$location[, 2],
                         xlim = c(floor(min(x$location[, 1])), ceiling(max(x$location[, 1]))),
@@ -83,7 +83,7 @@ plot.datagen<- function(x, plottype, time.index = NULL, ...) {
                         points(x$location[x$epidat[infectious, 1], 1], x$location[x$epidat[infectious, 1], 2], col = "red", pch = 19)
                         points(x$location[x$epidat[removed, 1], 1], x$location[x$epidat[removed, 1], 2], col = "green", pch = 19)
                         points(x$location[x$epidat[ss[m], 1], 1], x$location[x$epidat[ss[m], 1], 2], col = "blue", pch = 19)
-                        
+
                         if (any(m == seq.int(9, n, 9)) | (m == length(ss))) {
                             opar <- par(fig = c(0, 1, 0, 1), oma = c(0, 0, 0, 0),
                             mar = c(0, 0, 0, 0), new = TRUE)
@@ -107,17 +107,17 @@ plot.datagen<- function(x, plottype, time.index = NULL, ...) {
                         }
 
                     }
-                    
+
                 } else if (x$type == "SINR") {
 
                     op <- par(mar = c(5.9, 4.0, 1.5, 0.5), omi = c(0.2, 0.05, 0.15, 0.15), mfrow = c(a, b))
                     on.exit(par(op))
-                    
+
                     plot(x$location[, 1], x$location[, 2], xlim = c(floor(min(x$location[, 1])), ceiling(max(x$location[, 1]))),
                     ylim = c(floor(min(x$location[, 2])), ceiling(max(x$location[, 2]))), panel.first = grid(),
                     main =  paste("Infection time (",1,")"), xlab = "x", ylab = "y", col = "light gray", pch = 19)
                     points(x$location[x$epidat[1, 1], 1], x$location[x$epidat[1, 1], 2], col = "blue", pch = 16)
-         
+
                     for (m in 2:length(ss)) {
                         plot(x$location[, 1], x$location[, 2], xlim = c(floor(min(x$location[, 1])), ceiling(max(x$location[, 1]))),
                         ylim = c(floor(min(x$location[, 2])), ceiling(max(x$location[, 2]))),
@@ -129,7 +129,7 @@ plot.datagen<- function(x, plottype, time.index = NULL, ...) {
                         points(x$location[x$epidat[notified, 1], 1], x$location[x$epidat[notified, 1], 2], col = "yellow", pch = 19)
                         points(x$location[x$epidat[removed, 1], 1], x$location[x$epidat[removed, 1], 2], col = "green", pch = 19)
                         points(x$location[x$epidat[ss[m], 1], 1], x$location[x$epidat[ss[m], 1], 2], col = "blue", pch = 19)
-                        
+
                         if (any(m == seq.int(9, n, 9)) | (m == length(ss))) {
                             opar <- par(fig = c(0, 1, 0, 1), oma = c(0, 0, 0, 0),
                             mar = c(0, 0, 0, 0), new = TRUE)
@@ -148,13 +148,13 @@ plot.datagen<- function(x, plottype, time.index = NULL, ...) {
                                 pch = 20, col = c("gray", "blue", "red", "yellow", "green"),
                                 horiz = TRUE, bty = 'n', cex = 1.3)
                             }
-                            
+
                             op <- par(mar = c(5.9, 4.0, 1.5, 0.5), omi = c(0.2, 0.05, 0.15, 0.15), mfrow = c(a, b))
                             on.exit(par(op), add = TRUE)
                         }
 
                     }
-                    
+
                 }
 
                 on.exit(par(op1))
@@ -174,7 +174,7 @@ plot.datagen<- function(x, plottype, time.index = NULL, ...) {
                         plot(x$location[, 1], x$location[, 2], xlim = c(floor(min(x$location[, 1])), ceiling(max(x$location[, 1]))),
                         ylim = c(floor(min(x$location[, 2])), ceiling(max(x$location[, 2]))), panel.first = grid(),
                         main =  paste("Infection time (",1,")"), xlab = "x", ylab = "y", col = "dark gray", pch = 19)
-                    
+
                         for (i in 1:(n-1)) {
                             for (j in (i+1):n) {
                                 if (x$network[i,j] == 1) {
@@ -182,14 +182,14 @@ plot.datagen<- function(x, plottype, time.index = NULL, ...) {
                                 }
                             }
                         }
-                    
+
                         points(x$location[x$epidat[1, 1], 1], x$location[x$epidat[1, 1], 2], col = "red", pch = 19)
-                        
+
                         for (m in 2:length(ss)) {
                             plot(x$location[, 1], x$location[, 2], xlim = c(floor(min(x$location[, 1])), ceiling(max(x$location[, 1]))),
                             ylim = c(floor(min(x$location[, 2])), ceiling(max(x$location[, 2]))), panel.first = grid(),
                             main =  paste("Infection time (",ss[m],")"), xlab = "x", ylab = "y", pch = 19, col = "dark gray")
-                        
+
                             for (i in 1:(n-1)) {
                                 for (j in (i+1):n) {
                                     if (x$network[i,j] == 1) {
@@ -197,7 +197,7 @@ plot.datagen<- function(x, plottype, time.index = NULL, ...) {
                                     }
                                 }
                             }
-                        
+
                             points(x$location[, 1], x$location[, 2], col = "gray", pch = 16)
 
                             for (i in 1:(ss[m]-1)) {
@@ -212,20 +212,20 @@ plot.datagen<- function(x, plottype, time.index = NULL, ...) {
                                     }# network if-condition
                                 }# j for-loop
                             }# i for-loop
-                        
+
                             infectious <- which(x$epidat[1:(ss[m]-1), 4] < x$epidat[ss[m], 4] & x$epidat[(1:(ss[m]-1)), 2] > x$epidat[ss[m], 4])
                             removed    <- which(x$epidat[1:k1, 2] <= x$epidat[ss[m], 4])
                             points(x$location[x$epidat[ss[m], 1], 1], x$location[x$epidat[ss[m], 1], 2], col = "blue", pch = 19)
                             points(x$location[x$epidat[infectious, 1], 1], x$location[x$epidat[infectious, 1], 2], col = "red", pch = 19)
                             points(x$location[x$epidat[removed, 1], 1], x$location[x$epidat[removed, 1], 2], col = "green", pch = 19)
-                        
+
                             for (j in 1:length(infectious)) {
                                 if (x$network[x$epidat[infectious[j], 1], x$epidat[ss[m], 1]] == 1) {
                                     arrows(x$location[x$epidat[infectious[j], 1], 1], x$location[x$epidat[infectious[j], 1], 2],
                                     x$location[x$epidat[ss[m], 1], 1], x$location[x$epidat[ss[m], 1], 2], col = "blue", code = 2, length = 0.09)
                                 }# network if-condition
                             }# j for-loop
-                            
+
                             if (any(m == seq.int(9, n, 9)) | (m == length(ss))) {
                                 opar <- par(fig = c(0, 1, 0, 1), oma = c(0, 0, 0, 0),
                                 mar = c(0, 0, 0, 0), new = TRUE)
@@ -250,7 +250,7 @@ plot.datagen<- function(x, plottype, time.index = NULL, ...) {
                             }
 
                         }
-                        
+
                     } else if (x$type == "SINR") {
 
                         op <- par(mar = c(5.9, 4.0, 1.5, 0.5), omi = c(0.2, 0.05, 0.15, 0.15), mfrow = c(a, b))
@@ -259,7 +259,7 @@ plot.datagen<- function(x, plottype, time.index = NULL, ...) {
                         plot(x$location[, 1], x$location[, 2], xlim = c(floor(min(x$location[, 1])), ceiling(max(x$location[, 1]))),
                         ylim = c(floor(min(x$location[, 2])), ceiling(max(x$location[, 2]))), panel.first = grid(),
                         main =  paste("Infection time (",1,")"), xlab = "x", ylab = "y", col = "dark gray", pch = 19)
-                    
+
                         for (i in 1:(n-1)) {
                             for (j in (i+1):n) {
                                 if (x$network[i,j] == 1) {
@@ -267,14 +267,14 @@ plot.datagen<- function(x, plottype, time.index = NULL, ...) {
                                 }
                             }
                         }
-                    
+
                         points(x$location[x$epidat[1, 1], 1], x$location[x$epidat[1, 1], 2], col = "red", pch = 19)
-                        
+
                         for (m in 2:length(ss)) {
                             plot(x$location[, 1], x$location[, 2], xlim = c(floor(min(x$location[, 1])), ceiling(max(x$location[, 1]))),
                             ylim = c(floor(min(x$location[, 2])), ceiling(max(x$location[, 2]))), panel.first = grid(),
                             main =  paste("Infection time (",ss[m],")"), xlab = "x", ylab = "y", pch = 19, col = "dark gray")
-                        
+
                             for (i in 1:(n-1)) {
                                 for (j in (i+1):n) {
                                     if (x$network[i,j] == 1) {
@@ -282,7 +282,7 @@ plot.datagen<- function(x, plottype, time.index = NULL, ...) {
                                     }
                                 }
                             }
-                        
+
                             points(x$location[, 1], x$location[, 2], col = "gray", pch = 16)
 
                             for (i in 1:(ss[m]-1)) {
@@ -300,7 +300,7 @@ plot.datagen<- function(x, plottype, time.index = NULL, ...) {
                                     }# network if-condition
                                 }# j for-loop
                             }# i for-loop
-                        
+
                             notified    <- which(x$epidat[1:(ss[m]-1), 4]  < x$epidat[ss[m], 4] & x$epidat[(1:(ss[m]-1)), 2] > x$epidat[ss[m], 4])
                             infectious1 <- which(x$epidat[1:(ss[m]-1), 6]  < x$epidat[ss[m], 6] & x$epidat[(1:(ss[m]-1)), 4] > x$epidat[ss[m], 6])
                             infectious  <- which(x$epidat[1:(ss[m]-1), 6]  < x$epidat[ss[m], 6] & x$epidat[(1:(ss[m]-1)), 2] > x$epidat[ss[m], 6])
@@ -309,14 +309,14 @@ plot.datagen<- function(x, plottype, time.index = NULL, ...) {
                             points(x$location[x$epidat[infectious1, 1], 1], x$location[x$epidat[infectious1, 1], 2], col = "red", pch = 19)
                             points(x$location[x$epidat[notified, 1], 1], x$location[x$epidat[notified, 1], 2], col = "yellow", pch = 19)
                             points(x$location[x$epidat[removed, 1], 1], x$location[x$epidat[removed, 1], 2], col = "green", pch = 19)
-                        
+
                             for (j in 1:length(infectious)) {
                                 if (x$network[x$epidat[infectious[j], 1], x$epidat[ss[m], 1]] == 1) {
                                     arrows(x$location[x$epidat[infectious[j], 1], 1], x$location[x$epidat[infectious[j], 1], 2],
                                     x$location[x$epidat[ss[m], 1], 1], x$location[x$epidat[ss[m], 1], 2], col = "blue", code = 2, length = 0.09)
                                 }# network if-condition
                             }# j for-loop
-                            
+
                             if (any(m == seq.int(9, n, 9)) | (m == length(ss))) {
                                 opar <- par(fig = c(0, 1, 0, 1), oma = c(0, 0, 0, 0),
                                 mar = c(0, 0, 0, 0), new = TRUE)
@@ -335,14 +335,14 @@ plot.datagen<- function(x, plottype, time.index = NULL, ...) {
                                     pch = 20, col = c("gray", "blue", "red", "yellow", "green"),
                                     horiz = TRUE, bty = 'n', cex = 1.3)
                                 }
-                                
+
                                 op <- par(mar = c(5.9, 4.0, 1.5, 0.5), omi = c(0.2, 0.05, 0.15, 0.15), mfrow = c(a, b))
                                 on.exit(par(op), add = TRUE)
                             }
 
                         }
                     }
-                    
+
                     on.exit(par(op1))
 
                 } else {
@@ -353,12 +353,12 @@ plot.datagen<- function(x, plottype, time.index = NULL, ...) {
 
                     op <- par(mar = c(5.9, 4.0, 1.5, 0.5), omi = c(0.2, 0.05, 0.15, 0.15), mfrow = c(a, b))
                     on.exit(par(op))
-                    
+
                         plot(x$location[, 1], x$location[, 2], xlim = c(floor(min(x$location[,1])), ceiling(max(x$location[, 1]))),
                         ylim = c(floor(min(x$location[, 2])), ceiling(max(x$location[, 2]))), panel.first = grid(),
                         main =  paste("Infection time (",1,")"), xlab = "x", ylab = "y", col = "light gray", pch = 19)
                         points(x$location[x$epidat[1, 1], 1], x$location[x$epidat[1, 1], 2], col = "blue", pch = 16)
-                    
+
                         for (m in 2:length(ss)) {
                             plot(x$location[, 1], x$location[, 2], xlim = c(floor(min(x$location[, 1])), ceiling(max(x$location[, 1]))),
                             ylim = c(floor(min(x$location[, 2])), ceiling(max(x$location[, 2]))),
@@ -368,7 +368,7 @@ plot.datagen<- function(x, plottype, time.index = NULL, ...) {
                             points(x$location[x$epidat[infectious, 1], 1], x$location[x$epidat[infectious, 1], 2], col = "red", pch = 19)
                             points(x$location[x$epidat[removed, 1], 1], x$location[x$epidat[removed, 1], 2], col = "green", pch = 19)
                             points(x$location[x$epidat[ss[m], 1], 1], x$location[x$epidat[ss[m], 1], 2], col = "blue", pch = 19)
-                            
+
                             if (any(m == seq.int(9, n, 9)) | (m == length(ss))) {
                                 opar <- par(fig = c(0, 1, 0, 1), oma = c(0, 0, 0, 0),
                                 mar = c(0, 0, 0, 0), new = TRUE)
@@ -392,17 +392,17 @@ plot.datagen<- function(x, plottype, time.index = NULL, ...) {
                             }
 
                         }
-                        
+
                     } else if (x$type == "SINR") {
 
                         op <- par(mar = c(5.9, 4.0, 1.5, 0.5), omi = c(0.2, 0.05, 0.15, 0.15), mfrow = c(a, b))
                         on.exit(par(op))
-                
+
                         plot(x$location[, 1], x$location[, 2], xlim = c(floor(min(x$location[, 1])), ceiling(max(x$location[, 1]))),
                         ylim = c(floor(min(x$location[, 2])), ceiling(max(x$location[, 2]))), panel.first = grid(),
                         main =  paste("Infection time (",1,")"), xlab = "x", ylab = "y", col = "light gray", pch = 19)
                         points(x$location[x$epidat[1, 1], 1], x$location[x$epidat[1, 1], 2], col = "blue", pch = 16)
-         
+
                         for (m in 2:length(ss)) {
                             plot(x$location[, 1], x$location[, 2], xlim = c(floor(min(x$location[, 1])), ceiling(max(x$location[, 1]))),
                             ylim = c(floor(min(x$location[, 2])), ceiling(max(x$location[, 2]))),
@@ -414,7 +414,7 @@ plot.datagen<- function(x, plottype, time.index = NULL, ...) {
                             points(x$location[x$epidat[notified, 1], 1], x$location[x$epidat[notified, 1], 2], col = "yellow", pch = 19)
                             points(x$location[x$epidat[removed, 1], 1], x$location[x$epidat[removed, 1], 2], col = "green", pch = 19)
                             points(x$location[x$epidat[ss[m], 1], 1], x$location[x$epidat[ss[m], 1], 2], col = "blue", pch = 19)
-                            
+
                             if (any(m == seq.int(9, n, 9)) | (m == length(ss))) {
                                 opar <- par(fig = c(0, 1, 0, 1), oma = c(0, 0, 0, 0),
                                 mar = c(0, 0, 0, 0), new = TRUE)
@@ -438,9 +438,9 @@ plot.datagen<- function(x, plottype, time.index = NULL, ...) {
                             }
 
                         }
-                    
+
                     }
-                    
+
                     on.exit(par(op1))
 
                 }
@@ -459,7 +459,7 @@ plot.datagen<- function(x, plottype, time.index = NULL, ...) {
                         plot(x$location[, 1], x$location[, 2], xlim = c(floor(min(x$location[,1])), ceiling(max(x$location[, 1]))),
                         ylim = c(floor(min(x$location[, 2])), ceiling(max(x$location[, 2]))), panel.first = grid(),
                         main =  paste("Infection time (",1,")"), xlab = "x", ylab = "y", col = "dark gray", pch = 19)
-                    
+
                         for (i in 1:(n-1)) {
                             for (j in (i+1):n) {
                                 if (x$network[i,j] == 1) {
@@ -467,14 +467,14 @@ plot.datagen<- function(x, plottype, time.index = NULL, ...) {
                                 }
                             }
                         }
-                    
+
                         points(x$location[x$epidat[1, 1], 1], x$location[x$epidat[1, 1], 2], col = "red", pch = 19)
-                        
+
                         for (m in 2:length(ss)) {
                             plot(x$location[, 1], x$location[, 2], xlim = c(floor(min(x$location[, 1])), ceiling(max(x$location[, 1]))),
                             ylim = c(floor(min(x$location[, 2])), ceiling(max(x$location[, 2]))), panel.first = grid(),
                             main =  paste("Infection time (",ss[m],")"), xlab = "x", ylab = "y", pch = 19, col = "dark gray")
-                        
+
                             for (i in 1:(n-1)) {
                                 for (j in (i+1):n) {
                                     if (x$network[i,j] == 1) {
@@ -482,7 +482,7 @@ plot.datagen<- function(x, plottype, time.index = NULL, ...) {
                                     }
                                 }
                             }
-                        
+
                             points(x$location[, 1], x$location[, 2], col = "gray", pch = 16)
 
                             for (i in 1:(ss[m]-1)) {
@@ -497,20 +497,20 @@ plot.datagen<- function(x, plottype, time.index = NULL, ...) {
                                     }# network if-condition
                                 }# j for-loop
                             }# i for-loop
-                        
+
                             infectious <- which(x$epidat[(1:(ss[m]-1)), 4] < x$epidat[ss[m], 4] & x$epidat[(1:(ss[m]-1)), 2]>x$epidat[ss[m], 4])
                             removed    <- which(x$epidat[1:k1, 2] <=  x$epidat[ss[m], 4])
                             points(x$location[x$epidat[ss[m], 1], 1], x$location[x$epidat[ss[m], 1], 2], col = "blue", pch = 19)
                             points(x$location[x$epidat[infectious, 1], 1], x$location[x$epidat[infectious, 1], 2], col = "red", pch = 19)
                             points(x$location[x$epidat[removed, 1], 1], x$location[x$epidat[removed, 1], 2], col = "green", pch = 19)
-                        
+
                             for (j in 1:length(infectious)) {
                                 if (x$network[x$epidat[infectious[j], 1], x$epidat[ss[m], 1]] == 1) {
                                     segments(x$location[x$epidat[infectious[j], 1], 1], x$location[x$epidat[infectious[j], 1], 2],
                                     x$location[x$epidat[ss[m], 1], 1],x$location[x$epidat[ss[m], 1], 2], col = "blue")
                                 }# network if-condition
                             }# j for-loop
-                            
+
                             if (any(m == seq.int(9, n, 9)) | (m == length(ss))) {
                                 opar <- par(fig = c(0, 1, 0, 1), oma = c(0, 0, 0, 0),
                                 mar = c(0, 0, 0, 0), new = TRUE)
@@ -534,7 +534,7 @@ plot.datagen<- function(x, plottype, time.index = NULL, ...) {
                             }
 
                         }
-                        
+
                     } else if (x$type == "SINR") {
 
                         op <- par(mar = c(5.9, 4.0, 1.5, 0.5), omi = c(0.2, 0.05, 0.15, 0.15), mfrow = c(a, b))
@@ -543,7 +543,7 @@ plot.datagen<- function(x, plottype, time.index = NULL, ...) {
                         plot(x$location[, 1], x$location[, 2], xlim = c(floor(min(x$location[, 1])), ceiling(max(x$location[, 1]))),
                         ylim = c(floor(min(x$location[, 2])), ceiling(max(x$location[, 2]))), panel.first = grid(),
                         main =  paste("Infection time (",1,")"), xlab = "x", ylab = "y", col = "dark gray", pch = 19)
-                    
+
                         for (i in 1:(n-1)) {
                             for (j in (i+1):n) {
                                 if (x$network[i, j] == 1) {
@@ -551,14 +551,14 @@ plot.datagen<- function(x, plottype, time.index = NULL, ...) {
                                 }
                             }
                         }
-                    
+
                         points(x$location[x$epidat[1, 1], 1], x$location[x$epidat[1, 1], 2], col = "red", pch = 19)
-                        
+
                         for (m in 2:length(ss)) {
                             plot(x$location[, 1], x$location[, 2], xlim = c(floor(min(x$location[, 1])), ceiling(max(x$location[, 1]))),
                             ylim = c(floor(min(x$location[, 2])), ceiling(max(x$location[, 2]))), panel.first = grid(),
                             main =  paste("Infection time (",m,")"), xlab = "x", ylab = "y", pch = 19, col = "dark gray")
-                        
+
                             for (i in 1:(n-1)) {
                                 for (j in (i+1):n) {
                                     if (x$network[i, j] == 1) {
@@ -566,7 +566,7 @@ plot.datagen<- function(x, plottype, time.index = NULL, ...) {
                                     }
                                 }
                             }
-                        
+
                             points(x$location[, 1], x$location[, 2], col = "gray", pch = 16)
 
                             for (i in 1:(ss[m]-1)) {
@@ -581,20 +581,20 @@ plot.datagen<- function(x, plottype, time.index = NULL, ...) {
                                     }# network if-condition
                                 }# j for-loop
                             }# i for-loop
-                        
+
                             infectious <- which(x$epidat[1:(ss[m]-1), 6] <=  x$epidat[ss[m], 6] & x$epidat[(1:(ss[m]-1)), 2] > x$epidat[ss[m], 6])
                             removed    <- which(x$epidat[1:k1, 2] < x$epidat[ss[m], 6])
                             points(x$location[x$epidat[ss[m], 1], 1], x$location[x$epidat[ss[m], 1], 2], col = "blue", pch = 19)
                             points(x$location[x$epidat[infectious, 1], 1], x$location[x$epidat[infectious, 1], 2], col = "red", pch = 19)
                             points(x$location[x$epidat[removed, 1], 1], x$location[x$epidat[removed, 1], 2], col = "green", pch = 19)
-                        
+
                             for (j in 1:length(infectious)) {
                                 if (x$network[x$epidat[infectious[j], 1],x$epidat[ss[m], 1]] == 1) {
                                     segments(x$location[x$epidat[infectious[j], 1], 1], x$location[x$epidat[infectious[j], 1], 2],
                                     x$location[x$epidat[ss[m], 1], 1], x$location[x$epidat[ss[m], 1], 2], col = "blue")
                                 }# network if-condition
                             }# j for-loop
-                            
+
                             if (any(m == seq.int(9, n, 9)) | (m == length(ss))) {
                                 opar <- par(fig = c(0, 1, 0, 1), oma = c(0, 0, 0, 0),
                                 mar = c(0, 0, 0, 0), new = TRUE)
@@ -620,7 +620,7 @@ plot.datagen<- function(x, plottype, time.index = NULL, ...) {
                         }
 
                     }
-                    
+
                     on.exit(par(op1))
 
                 } else {
@@ -628,15 +628,15 @@ plot.datagen<- function(x, plottype, time.index = NULL, ...) {
                     op1 <- par(no.readonly = TRUE)
 
                     if (x$type == "SIR") {
-                        
+
                         op <- par(mar = c(5.9, 4.0, 1.5, 0.5), omi = c(0.2, 0.05, 0.15, 0.15), mfrow = c(a, b))
                         on.exit(par(op))
-                    
+
                         plot(x$location[, 1], x$location[, 2], xlim = c(floor(min(x$location[, 1])), ceiling(max(x$location[, 1]))),
                         ylim = c(floor(min(x$location[, 2])), ceiling(max(x$location[, 2]))), panel.first = grid(),
                         main =  paste("Infection time (",1,")"), xlab = "x", ylab = "y", col = "light gray", pch = 19)
                         points(x$location[x$epidat[1, 1], 1], x$location[x$epidat[1, 1], 2], col = "blue", pch = 16)
-                    
+
                         for (m in 1:length(ss)) {
                             plot(x$location[, 1], x$location[, 2], xlim = c(floor(min(x$location[, 1])), ceiling(max(x$location[, 1]))),
                             ylim = c(floor(min(x$location[, 2])), ceiling(max(x$location[, 2]))),
@@ -646,7 +646,7 @@ plot.datagen<- function(x, plottype, time.index = NULL, ...) {
                             points(x$location[x$epidat[infectious, 1], 1], x$location[x$epidat[infectious, 1], 2], col = "red", pch = 19)
                             points(x$location[x$epidat[removed, 1], 1], x$location[x$epidat[removed, 1], 2], col = "green", pch = 19)
                             points(x$location[x$epidat[ss[m], 1], 1], x$location[x$epidat[ss[m], 1], 2], col = "blue", pch = 19)
-                            
+
                             if (any(m == seq.int(9, n, 9)) | (m == length(ss))) {
                                 opar <- par(fig = c(0, 1, 0, 1), oma = c(0, 0, 0, 0),
                                 mar = c(0, 0, 0, 0), new = TRUE)
@@ -670,17 +670,17 @@ plot.datagen<- function(x, plottype, time.index = NULL, ...) {
                             }
 
                         }
-                        
+
                     } else if (x$type == "SINR") {
 
                         op <- par(mar = c(5.9, 4.0, 1.5, 0.5), omi = c(0.2, 0.05, 0.15, 0.15), mfrow = c(a, b))
                         on.exit(par(op))
-                    
+
                         plot(x$location[, 1], x$location[, 2], xlim = c(floor(min(x$location[, 1])), ceiling(max(x$location[, 1]))),
                         ylim = c(floor(min(x$location[, 2])), ceiling(max(x$location[, 2]))), panel.first = grid(),
                         main = paste("Infection time (",1,")"), xlab = "x", ylab = "y", col = "light gray", pch = 19)
                         points(x$location[x$epidat[1, 1], 1], x$location[x$epidat[1, 1], 2], col = "blue", pch = 16)
-         
+
                         for (m in 2:length(ss)) {
                             plot(x$location[, 1], x$location[, 2], xlim = c(floor(min(x$location[, 1])), ceiling(max(x$location[, 1]))),
                             ylim = c(floor(min(x$location[, 2])), ceiling(max(x$location[,2]))),
@@ -692,7 +692,7 @@ plot.datagen<- function(x, plottype, time.index = NULL, ...) {
                             points(x$location[x$epidat[notified, 1], 1], x$location[x$epidat[notified, 1], 2], col = "yellow", pch = 19)
                             points(x$location[x$epidat[removed, 1], 1], x$location[x$epidat[removed, 1], 2], col = "green", pch = 19)
                             points(x$location[x$epidat[ss[m], 1], 1], x$location[x$epidat[ss[m], 1], 2], col = "blue", pch = 19)
-                            
+
                             if (any(m == seq.int(9, n, 9)) | (m == length(ss))) {
                                 opar <- par(fig = c(0, 1, 0, 1), oma = c(0, 0, 0, 0),
                                 mar = c(0, 0, 0, 0), new = TRUE)
@@ -716,9 +716,9 @@ plot.datagen<- function(x, plottype, time.index = NULL, ...) {
                             }
 
                         }
-                    
+
                     }
-                    
+
                     on.exit(par(op1))
 
                 }
@@ -738,9 +738,9 @@ plot.datagen<- function(x, plottype, time.index = NULL, ...) {
                 plot(density(x$epidat[1:k1, 2], from = min(x$epidat[1:k1, 2])), main = "Epidemic curve of \n the removal times", xlab = "Removal times")
                 plot(x$epidat[1:k1, 4], type = "l",main = "The epidemic time-lines history",ylim = c(min(x$epidat[1:k1, 4]),max(x$epidat[1:k1, 2])), ylab = "event times", xlab = "Time points")
                 lines(x$epidat[1:k1, 2], col = "black")
-                
+
                 polygon(c(seq(1, k1), rev(seq(1, k1))), c(x$epidat[1:k1, 4], rev(x$epidat[1:k1, 2])), col = "red", border = NA)
-            
+
             } else if (x$type == "SINR") {
                 op <- par(mar = c(5.1, 4.1, 4.1, 2.1), omi = c(0, 0, 0, 0), mfrow = c(2, 2))
                 on.exit(par(op))
@@ -748,7 +748,7 @@ plot.datagen<- function(x, plottype, time.index = NULL, ...) {
                 plot(density(x$epidat[1:k1, 6], from = min(x$epidat[1:k1, 6])), main = "Epidemic curve of \n the infection times", xlab = "Infection times")
                 plot(density(x$epidat[1:k1, 4], from = min(x$epidat[1:k1, 4])), main = "Epidemic curve of \n the notification times", xlab = "Notification times")
                 plot(density(x$epidat[1:k1, 2], from = min(x$epidat[1:k1, 2])), main = "Epidemic curve of \n the removal times", xlab = "Removal times")
-                
+
                 plot(x$epidat[1:k1, 6], type = "l", main = "The epidemic time-line history", ylim = c(min(x$epidat[1:k1, 6]), max(x$epidat[1:k1, 2])), ylab = "event times", xlab = "Time points")
                 lines(x$epidat[1:k1, 4], col = "black")
                 lines(x$epidat[1:k1, 2], col = "black")
@@ -756,11 +756,11 @@ plot.datagen<- function(x, plottype, time.index = NULL, ...) {
                 polygon(c(seq(1, k1), rev(seq(1, k1))), c(x$epidat[1:k1, 4], rev(x$epidat[1:k1, 2])), col = "blue", border = NA)
 
             }
-            
+
             on.exit(par(op1))
 
         }
-        
+
     } else {
         stop("The class of x must be a class of datagen", call. = FALSE)
     }
